@@ -5,14 +5,14 @@
 # http://www.zotero.org/support/kb/ssl_certificate_error
 # names(getCurlOptionsConstants())
 # http://www.zotero.org/support/dev/server_api/v2/write_requests
-# 
+#
 # http://www.omegahat.org/RCurl/philosophy.html
 # .opts explained: http://curl.haxx.se/libcurl/c/curl_easy_setopt.html
 
 #' Get Bibliography Information From a Zotero Library.
-#' 
-#' @param user Zotero userID for use in calls to the Zotero API.  This is not the same as your Zotero 
-#'   username.  The userID for accessing user-owned libraries can be found at 
+#'
+#' @param user Zotero userID for use in calls to the Zotero API.  This is not the same as your Zotero
+#'   username.  The userID for accessing user-owned libraries can be found at
 #'   \url{https://www.zotero.org/settings/keys}.
 #' @param .params A \emph{named} list of parameters to use in requests to the Zotero API with possible values
 #'  \itemize{
@@ -35,63 +35,71 @@
 #' @examples
 #' \dontrun{
 #' ## first two entries in library with bayesian in title
-#' ReadZotero(user='1648676', .params=list(q='bayesian', key='7lhgvcwVq60CDi7E68FyE3br', 
+#' ReadZotero(user='1648676', .params=list(q='bayesian', key='7lhgvcwVq60CDi7E68FyE3br',
 #'   limit=2))
 #'
 #' ## Search specific collection
 #' ## collection key can be found by reading uri when collection is selected in Zotero
-#' ReadZotero(user='1648676', .params=list(q='yu', key='7lhgvcwVq60CDi7E68FyE3br', 
+#' ReadZotero(user='1648676', .params=list(q='yu', key='7lhgvcwVq60CDi7E68FyE3br',
 #'   collection='3STEQRNU'))
 #'
 #' ## Search by tag
 #' ## Notice the issue with how Zotero uses a TechReport entry for arXiv manuscripts
 #' ## This is one instance where the added fields of BibLaTeX are useful
-#' ReadZotero(user='1648676', .params=list(key='7lhgvcwVq60CDi7E68FyE3br', 
+#' ReadZotero(user='1648676', .params=list(key='7lhgvcwVq60CDi7E68FyE3br',
 #'   tag='Statistics - Machine Learning'))
 #'
-#' ## To read these in you must set check.entries to FALSE or "warn"   
+#' ## To read these in you must set check.entries to FALSE or "warn"
 #' BibOptions(check.entries = FALSE)
-#' ReadZotero(user='1648676', .params=list(key='7lhgvcwVq60CDi7E68FyE3br', 
+#' ReadZotero(user='1648676', .params=list(key='7lhgvcwVq60CDi7E68FyE3br',
 #'   tag='Statistics - Machine Learning'))
 #' }
 #' @keywords database
 ReadZotero <- function(user, .params, temp.file = tempfile(fileext = '.bib'), delete.file = TRUE){
   if (delete.file)
     on.exit(unlink(temp.file, force = TRUE))
-  
+
   bad.ind <- which(!names(.params) %in% c('q', 'itemType', 'tag', 'collection', 'key', 'limit', 'start', 'qmode'))
   .parms <- .params
-  if(length(bad.ind)){
+  if (length(bad.ind)){
     warning('Invalid .params specified and will be ignored')
     .parms <- .parms[-bad.ind]
   }
   .parms$format <- 'bibtex'
-  if(is.null(.parms$limit))
+  if (is.null(.parms$limit))
     .parms$limit <- 99L
-  
-  if(is.null(.params$collection)){
-    .parms$uri <- paste('https://api.zotero.org/users/', user, '/items', sep='')
-  }else{
-    .parms$uri <- paste('https://api.zotero.org/users/', user, '/collections/', .params$collection, '/items', sep='')
-  }
-  
+
+  .parms$uri <- if (is.null(.params$collection))
+     paste('https://api.zotero.org/users/', user, '/items', sep='')
+  else
+    paste('https://api.zotero.org/users/', user, '/collections/',
+          .params$collection, '/items', sep='')
+
   cert <- try(system.file("CurlSSL/cacert.pem", package = "RCurl"))
-  if(class(cert)=='try-error'){
-    .parms$.opts <- curlOptions(ssl.verifypeer=FALSE, httpheader='Zotero-API-Version: 2', forbid.reuse=TRUE)
-  }else{
-    .parms$.opts <- curlOptions(ssl.verifypeer=TRUE, httpheader='Zotero-API-Version: 2', forbid.reuse=TRUE, cainfo=cert)
-  }
-  
+  .parms$.opts <- if (class(cert)=='try-error')
+      curlOptions(ssl.verifypeer=FALSE, httpheader='Zotero-API-Version: 2',
+                  forbid.reuse=TRUE)
+  else
+    curlOptions(ssl.verifypeer=TRUE, httpheader='Zotero-API-Version: 2',
+               forbid.reuse=TRUE, cainfo=cert)
+
   res <- do.call(getForm, .parms)
-                  
-  if(class(res)=='raw') # not sure why this happens. happens with getForm sometimes, but not with getURL for same uri
+  ## not sure why this happens. happens with getForm sometimes, but
+  ##   not with getURL for same uri
+  if (class(res)=='raw')
     res <- rawToChar(res)
-  
-  if(res==''){
+
+  if (res == ''){
     print('No results.')
     return()
   }
-  write(res, file=temp.file)
-                  
-  ReadBib(temp.file)
+  write(res, file=temp.file, append = TRUE)
+
+  bib.res <- try(ReadBib(file=temp.file, .Encoding='UTF-8'), TRUE)
+  if (inherits(bib.res, "try-error")){
+    message(paste0("Error parsing the returned BibTeX results.  If delete.file ",
+                   "is FALSE, you can try viewing and editing the file: ", temp.file))
+    return()
+  }
+  bib.res
 }
